==> dhall-json-1.7.12-164-loong64.pkg.tar.zst: usr/share/haskell/register/dhall-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-json
version:              1.7.12
visibility:           public
id:                   dhall-json-1.7.12-DNkntXMNk15AAJ0w8mbM6T
key:                  dhall-json-1.7.12-DNkntXMNk15AAJ0w8mbM6T
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and JSON or YAML
description:
    Use this package if you want to convert between Dhall expressions and JSON
    or YAML. You can use this package as a library or an executable:

    * See the "Dhall.JSON" or "Dhall.JSONToDhall" modules if you want to use
    this package as a library

    * Use the @dhall-to-json@, @dhall-to-yaml@, or @json-to-dhall@ programs from
    this package if you want an executable

    The "Dhall.JSON" and "Dhall.JSONToDhall" modules also contains instructions
    for how to use this package

category:             Compiler
abi:                  c6520dc8f3f67de14d3487555336c39f
exposed:              True
exposed-modules:
    Dhall.DhallToYaml.Main Dhall.JSON Dhall.JSON.Yaml Dhall.JSONToDhall

hidden-modules:       Dhall.JSON.Compat Dhall.JSON.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-json
hs-libraries:         HSdhall-json-1.7.12-DNkntXMNk15AAJ0w8mbM6T
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    aeson-pretty-0.8.10-BjxB783FV8e8YPhrNbMs4J
    aeson-yaml-1.1.0.1-EfKrrrtnDCa8zZ3MDMeuVe base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.3-6ivmxcjn5ctBDS3CQUifdU exceptions-0.10.7
    filepath-1.4.300.1 lens-family-core-2.1.3-ATkyQy7CaRL9XkLMxregni
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/dhall-json/html/dhall-json.haddock
haddock-html:         /usr/share/doc/dhall-json/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-json-1.7.12-167-loong64.pkg.tar.zst: usr/share/haskell/register/dhall-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-json
version:              1.7.12
visibility:           public
id:                   dhall-json-1.7.12-8jxhcocVQAaBGx0D22Ooi
key:                  dhall-json-1.7.12-8jxhcocVQAaBGx0D22Ooi
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and JSON or YAML
description:
    Use this package if you want to convert between Dhall expressions and JSON
    or YAML. You can use this package as a library or an executable:

    * See the "Dhall.JSON" or "Dhall.JSONToDhall" modules if you want to use
    this package as a library

    * Use the @dhall-to-json@, @dhall-to-yaml@, or @json-to-dhall@ programs from
    this package if you want an executable

    The "Dhall.JSON" and "Dhall.JSONToDhall" modules also contains instructions
    for how to use this package

category:             Compiler
abi:                  fb4c9f5b12daa795e257b0a4ba8ebf85
exposed:              True
exposed-modules:
    Dhall.DhallToYaml.Main Dhall.JSON Dhall.JSON.Yaml Dhall.JSONToDhall

hidden-modules:       Dhall.JSON.Compat Dhall.JSON.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-json
hs-libraries:         HSdhall-json-1.7.12-8jxhcocVQAaBGx0D22Ooi
depends:
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH
    aeson-pretty-0.8.10-eT1JM8BphwIKZ7kNgAtSZ
    aeson-yaml-1.1.0.1-JFOcosopXBv1fAnmTLCtBu base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.3-EidAGmin8lt7mPY3yHO1CI exceptions-0.10.7
    filepath-1.4.300.1 lens-family-core-2.1.3-ATkyQy7CaRL9XkLMxregni
    optparse-applicative-0.18.1.0-EZi3UgmTFLmKW119EQEIXK
    prettyprinter-1.7.1-LgLGkLn2CvpBXnv6jAGI5w
    scientific-0.3.8.0-E8K90IhCZpR98POp8HwlML text-2.0.2
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O
    vector-0.13.2.0-DULMVARQ1CU3TLBOg9xkS6

haddock-interfaces:   /usr/share/doc/dhall-json/html/dhall-json.haddock
haddock-html:         /usr/share/doc/dhall-json/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
